@@ -7,6 +7,9 @@ import zipfile
 import os
 import gspm.utils.process_utils as process_utils
 import subprocess
+import requests
+import sys
+from urllib.parse import urlparse
 
 from packaging.version import Version
 from gspm.utils.versions import *
@@ -76,10 +79,13 @@ def install_godot(project):
         logging.debug(
             "- downloading [{0}] to [{1}]".format(uri, dest_path))
 
-        file = wget.download(uri, dest_path)
-
+        # file = wget.download(uri, dest_path)
+        file = os.path.join(dest_path, "file.zip")
+        # get = requests.get(uri)
+        # with open(file, 'wb') as code:
+        #     code.write(get.content)
+        download(uri, file)
         logging.log(99, "\r")
-        
         logging.info("\r- dowload complete")
         zipf = zipfile.ZipFile(file)
         zipf.extractall(dest_path)
@@ -351,3 +357,20 @@ def _get_darwin_runtime(project):
 
     return runtime
 
+def download(url, filename):
+    with open(filename, 'wb') as f:
+        response = requests.get(url, stream=True)
+        total = response.headers.get('content-length')
+
+        if total is None:
+            f.write(response.content)
+        else:
+            downloaded = 0
+            total = int(total)
+            for data in response.iter_content(chunk_size=max(int(total/1000), 1024*1024)):
+                downloaded += len(data)
+                f.write(data)
+                done = int(50*downloaded/total)
+                sys.stdout.write('\r[{}{}]'.format('█' * done, '.' * (50-done)))
+                sys.stdout.flush()
+    sys.stdout.write('\n')
\ No newline at end of file
