@@ -262,4 +262,37 @@ godot_versions = {
     ':3.3.2::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_x11_64.zip',
     ':3.3.2::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_win32.zip',
     ':3.3.2::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_win64.zip',
+# 3.3.3
+    ':3.3.3::darwin::'             : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_osx.universal.zip',
+    ':3.3.3::linux:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_x11.32.zip',
+    ':3.3.3::linux:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_x11.64.zip',
+    ':3.3.3::windows:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_win64.exe.zip',
+    ':3.3.3::windows:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_win32.exe.zip',
+    ':3.3.3::darwin::mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_osx.64.zip',
+    ':3.3.3::linux:32:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_x11_32.zip',
+    ':3.3.3::linux:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_x11_64.zip',
+    ':3.3.3::windows:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_win32.zip',
+    ':3.3.3::windows:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_win64.zip',
+# 3.3.4
+    ':3.3.4::darwin::'             : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_osx.universal.zip',
+    ':3.3.4::linux:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_x11.32.zip',
+    ':3.3.4::linux:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_x11.64.zip',
+    ':3.3.4::windows:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_win64.exe.zip',
+    ':3.3.4::windows:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_win32.exe.zip',
+    ':3.3.4::darwin::mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_osx.64.zip',
+    ':3.3.4::linux:32:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_x11_32.zip',
+    ':3.3.4::linux:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_x11_64.zip',
+    ':3.3.4::windows:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_win32.zip',
+    ':3.3.4::windows:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_win64.zip',
+# 3.4
+    ':3.4::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_osx.universal.zip',
+    ':3.4::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_x11.32.zip',
+    ':3.4::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_x11.64.zip',
+    ':3.4::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_win64.exe.zip',
+    ':3.4::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_win32.exe.zip',
+    ':3.4::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_osx.64.zip',
+    ':3.4::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_x11_32.zip',
+    ':3.4::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_x11_64.zip',
+    ':3.4::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_win32.zip',
+    ':3.4::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_win64.zip',
 }
